@@ -1,3 +1,5 @@
+from enum import Enum
+
 from wedeliver_core.helpers.service_config import ServiceConfig
 
 
@@ -17,3 +19,9 @@ class Service:
     ADDRESS = ServiceConfig('ADDRESS_SERVICE')
     PUBLIC = ServiceConfig('PUBLIC_SERVICE')
     INTERNAL_NOTIFICATION = ServiceConfig('INTERNAL_NOTIFICATION_SERVICE')
+
+
+class QueryTypes(Enum):
+    SIMPLE_TABLE = 1
+    FUNCTION = 2
+    SEARCH = 3
