@@ -208,6 +208,10 @@ class MicroFetcher(object):
                 for _input in item.get('inputs'):
                     for _index in _input.get('indexes'):
                         self.base_data[_index][self.output_key] = _input.get('matched_id')
+                        append_extra = self.search_configs.get('append_extra') if isinstance(self.search_configs, dict) else []
+                        for _ap_col in append_extra:
+                            self.base_data[_index][_ap_col] = _input.get(_ap_col)
+
             validation_result = []
             for _val in result.get("validation"):
                 for _ind in _val.get("indexes"):
